#Install relevant packages
install.packages("MASS")
install.packages("effects")
install.packages("car")
install.packages("foreign")
            

#Load package
library("MASS")
library("effects")
library("splines")
library("car")
library("foreign")

#Read data file from UCL mAchine learning repository  
setwd("C:/Users/A.ASIJA/Desktop")
data <- read.table("data.txt")
head(data)

#Ordering the dependent variable
data$rpurchase = factor(data$rpurchase, levels = c("low probability", "medium probability", "high probability"), ordered = TRUE) 
data$peers = factor(data$peers, levels = c("0", "1"), ordered = TRUE) 
data$coupon = factor(data$coupon, levels = c("0", "1"), ordered = TRUE) 


#Summarizing the data
summary(data)

#Making frequency table
table(data$rpurchase, data$coupon)

#Random sampling 
samplesize = 0.60*nrow(data)
set.seed(100)
index = sample(seq_len(nrow(data)), size = samplesize)

#Creating training and test set 
datatrain = data[index,]
datatest = data[-index,]

#Build ordinal logistic regression model
model= polr( rpurchase ~ coupon + peers + quality , data = datatrain, Hess = TRUE)
summary(model)
Anova(model)


#Compute confusion table and misclassification error
predictrpurchase = predict(model,datatest)
table(datatest$rpurchase, predictrpurchase)
mean(as.character(datatest$rpurchase) != as.character(predictrpurchase))


#Plotting the effects 
Effect(focal.predictors = "quality",model)
plot(Effect(focal.predictors = "coupon",model))
plot(Effect(focal.predictors = c("quality", "coupon"),model))






